Method: MongoMapper::Serialization#to_json
- Defined in:
- lib/mongomapper/serializers/json_serializer.rb
#to_json(options = {}) ⇒ Object
Returns a JSON string representing the model. Some configuration is available through options.
The option include_root_in_json controls the top-level behavior of to_json. When it is true, to_json will emit a single root node named after the object’s type. For example:
konata = User.find(1)
User.include_root_in_json = true
konata.to_json
# => { "user": {"id": 1, "name": "Konata Izumi", "age": 16,
"created_at": "2006/08/01", "awesome": true} }
User.include_root_in_json = false
konata.to_json
# => {"id": 1, "name": "Konata Izumi", "age": 16,
"created_at": "2006/08/01", "awesome": true}
The remainder of the examples in this section assume include_root_in_json is set to false.
Without any options, the returned JSON string will include all the model’s attributes. For example:
konata = User.find(1)
konata.to_json
# => {"id": 1, "name": "Konata Izumi", "age": 16,
"created_at": "2006/08/01", "awesome": true}
The :only and :except options can be used to limit the attributes included, and work similar to the attributes method. For example:
konata.to_json(:only => [ :id, :name ])
# => {"id": 1, "name": "Konata Izumi"}
konata.to_json(:except => [ :id, :created_at, :age ])
# => {"name": "Konata Izumi", "awesome": true}
To include any methods on the model, use :methods.
konata.to_json(:methods => :permalink)
# => {"id": 1, "name": "Konata Izumi", "age": 16,
"created_at": "2006/08/01", "awesome": true,
"permalink": "1-konata-izumi"}
52 53 54 55 56 57 58 59 60 |
# File 'lib/mongomapper/serializers/json_serializer.rb', line 52 def to_json( = {}) apply_to_json_defaults() if include_root_in_json "{#{self.class.json_class_name}: #{JsonSerializer.new(self, ).to_s}}" else JsonSerializer.new(self, ).to_s end end |